==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/my_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_membership_info'] = 					"membership information";
$lang['hdr_membership'] = 						"membership";
$lang['hdr_email_info'] = 						"email settings";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_sub_rss'] = 							"your rss feeds";
$lang['hdr_sub_email'] = 						"your email subscriptions";


//SUBMIT BUTTONS
$lang['sub_update'] = 							"update";


//HREF
$lang['href_edit_membership'] = 				"edit membership";


//BODY TEXT
$lang['txt_confirm_email'] =					"confirm email";
$lang['txt_confirm_password'] =					"confirm password";
$lang['txt_dob'] =								"date of birth";
$lang['txt_email'] =							"email";
$lang['txt_firstname'] =						"firstname";
$lang['txt_gender'] =							"gender";
$lang['txt_gender_female'] =					"female";
$lang['txt_gender_male'] =						"male";
$lang['txt_gender_none'] = 						"undisclosed";
$lang['txt_hometown'] =							"home town";
$lang['txt_password'] =							"password";
$lang['txt_pref_lang'] =						"preferred language";
$lang['txt_surname'] =							"surname";
$lang['txt_template'] =							"template";
$lang['txt_lang_selection'] = 					"languages";
$lang['txt_membership_number'] =				"membership number";
$lang['txt_homepage'] = 						"home page";
$lang['txt_rss_help'] = 						"An RSS feed is available for this community. Please note, if you change your password you will need to recreate this feed. See the help group for more information on RSS.";
$lang['txt_hometown_help'] =					"Home town hint: Your home town is the place where you are living now.";
$lang['txt_password_help'] =					"Password hint: Use something that no one will guess. Your password has to be at least 5 characters long.";
$lang['txt_lang_help'] =						"Language hint: Select you preferred language to see the screens displayed in that language. Articles will be displayed written in the languages you select from the 'languages' option.";
$lang['txt_template_help'] =					"Template hint: A template is like a 'theme'; if is the look and feel of the screens.";
$lang['txt_email_set_help'] = 					"You can change your email address at any time. Type in your new email address and confirm. When you press 'update' you will be sent an email to that email address. You need to press the link in the email address to log back in with you new email address.";
$lang['txt_email_message_help'] = 				"Check the box to send you a notification email when you receive a message.";
$lang['txt_digest_newsletter_help'] = 			"Check the box to receive a weekly digest newsletter containing movement against your bookmarks, new events, group information and statistics.";

?>

==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/my_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_membership_info'] = 					"membership information";
$lang['hdr_membership'] = 						"membership";
$lang['hdr_email_info'] = 						"email settings";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_sub_rss'] = 							"your rss feeds";
$lang['hdr_sub_email'] = 						"your email subscriptions";


//HREF
$lang['href_edit_membership'] = 				"edit membership";


//BODY TEXT
$lang['txt_confirm_email'] =					"confirm email";
$lang['txt_confirm_password'] =					"confirm password";
$lang['txt_dob'] =								"date of birth";
$lang['txt_email'] =							"email";
$lang['txt_firstname'] =						"firstname";
$lang['txt_password'] =							"password";
$lang['txt_pref_lang'] =						"preferred language";
$lang['txt_surname'] =							"surname";
$lang['txt_template'] =							"template";
$lang['txt_lang_selection'] = 					"languages";
$lang['txt_membership_number'] =				"membership number";
$lang['txt_homepage'] = 						"home page";
$lang['txt_rss_help'] = 						"An RSS feed is available for this community. Please note, if you change your password you will need to recreate this feed. See the help group for more information on RSS.";
$lang['txt_hometown_help'] =					"Home town hint: Your home town is the place where you are living now.";
$lang['txt_password_help'] =					"Password hint: Use something that no one will guess. Your password has to be at least 5 characters long.";
$lang['txt_lang_help'] =						"Language hint: Select you preferred language to see the screens displayed in that language. Articles will be displayed written in the languages you select from the 'languages' option.";
$lang['txt_template_help'] =					"Template hint: A template is like a 'theme'; if is the look and feel of the screens.";
$lang['txt_email_set_help'] = 					"You can change your email address at any time. Type in your new email address and confirm. When you press 'update' you will be sent an email to that email address. You need to press the link in the email address to log back in with you new email address.";
$lang['txt_email_message_help'] = 				"Check the box to send you a notification email when you receive a message.";
$lang['txt_digest_newsletter_help'] = 			"Check the box to receive a weekly digest newsletter containing movement against your bookmarks, new events, group information and statistics.";


// MESSAGES AND EMAIL
$lang['subject_new_details'] = 						"Your new AROUNDMe details!";

?>
